@@ -1,5 +1,11 @@
+from django.conf import settings
+if 'south' in settings.INSTALLED_APPS:
+    from south.modelsinspector import add_introspection_rules
+    add_introspection_rules([], ["^ipyfield\.models\.IPyField"])
+
+
 from django.db import models
-from ipyfield import IP
+from IPy import IP
 
 
 class IPyField(models.Field):
@@ -21,7 +27,7 @@ class IPyField(models.Field):
         value = self.to_python(value)
         if not value:
             return None
-        return value.int()
+        return str(value.int())
 
     def to_string(self, obj):
         value = self._get_val_from_obj(obj)
@@ -32,11 +38,14 @@ class IPyField(models.Field):
             if isinstance(value, str):
                 value = IP(value)
             return [self.get_prep_value(v) for v in value]
-        elif lookup_type == 'exact':
+        elif lookup_type in ['exact', 'lt', 'lte', 'gt', 'gte']:
             return self.get_prep_value(value)
         else:
             raise TypeError('Lookup type %r not supported.' % lookup_type)
 
+    def db_type(self, connection):
+        return 'varchar(39)'
+
     def get_internal_type(self):
-        return 'BigIntegerField'
+        return 'CharField'
 
